#!/usr/bin/perl -Tw

#######################################################
#
# Family Tree generation program, v2.0
# Written by Ferenc Bodon and Simon Ward, March 2000 (simonward.com)
# Copyright (C) 2000 Ferenc Bodon, Simon K Ward
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# For a copy of the GNU General Public License, visit 
# http://www.gnu.org or write to the Free Software Foundation, Inc.,
# 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
#######################################################

package Name;
use strict;
use warnings;
use Params::Validate qw(:all);

my $reverseOrder = 0;
sub setReverseOrder {
    $reverseOrder = $_[0];
}

sub new {
  my ( $classname, $first_name, $last_name) = @_;
  my $self = {
     title => undef,
     prefix => undef,
     first_name => defined $first_name ? $first_name : "",
     mid_name => undef,
     last_name => defined $last_name ? $last_name: "",
     suffix => undef,
     nickname => undef,
  };
  return bless $self, $classname;
}
sub setName {
  my ( $self, $first_name, $mid_name, $last_name) = validate_pos(@_, 
    {type => HASHREF}, {type => SCALAR|UNDEF}, {type => SCALAR|UNDEF}, {type => SCALAR|UNDEF} );
  $self->{first_name} = $first_name; 
  $self->{mid_name} = $mid_name;
  $self->{last_name} = $last_name;
}
sub setTitle {
  my ( $self, $title ) = validate_pos(@_, 
    {type => HASHREF}, {type => SCALAR} );
  $self->{title} = $title;
}

sub setPrefix {
  my ( $self, $prefix ) = validate_pos(@_, 
    {type => HASHREF}, {type => SCALAR} );
  $self->{prefix} = $prefix;
}

sub setSuffix {
  my ( $self, $suffix ) = validate_pos(@_, 
    {type => HASHREF}, {type => SCALAR} );
  $self->{suffix} = $suffix;
}
sub setNickname {
  my ( $self, $nickname ) = validate_pos(@_, 
    {type => HASHREF}, {type => SCALAR} );
  $self->{nickname} = $nickname;
}

sub full_name {
  my ( $self) = validate_pos(@_, {type => HASHREF});
  if(defined $self->{mid_name} && $self->{mid_name} ne "") {
    if($reverseOrder) {
      return join(" ", ($self->{last_name}, $self->{mid_name}, $self->{first_name}));
    }
    else {
      return join(" ", ($self->{first_name}, $self->{mid_name}, $self->{last_name}));
    }
  }
  else {
    if($reverseOrder) {
      return join(" ", ($self->{last_name}, $self->{first_name}));
    }
    else {
      return join(" ", ($self->{first_name},$self->{last_name}));
    }
  }  
}
sub long_name {
  my ( $self) = validate_pos(@_, {type => HASHREF});
  my $long_name = "";
  $long_name.= $self->{title}." "
  	if(defined $self->{title}); 
  $long_name.= $self->{prefix}." "
  	if(defined $self->{prefix});
  $long_name.= $self->full_name();
  $long_name.= " ".$self->{suffix}
  	if(defined $self->{suffix});
  return $long_name;
}
sub short_name {
    my ( $self) = validate_pos(@_, {type => HASHREF});
    if($reverseOrder) {
    	return join(" ", ($self->{last_name},$self->{first_name}));  		
    }
    else {
		return join(" ", ($self->{first_name},$self->{last_name}));
    }
}
#######################################################
# converts a name to a url
# (removes middle name and converts spaces)
sub urlname {
  my ( $self ) = validate_pos(@_, {type => HASHREF});
  my $full_name = $self->full_name();
  $full_name =~ s/ /%20/g;
  return $full_name;
}
1;