#!/usr/bin/perl -Tw

#######################################################
#
# Family Tree generation program, v2.0
# Written by Ferenc Bodon and Simon Ward, March 2000 (simonward.com)
# Copyright (C) 2000 Ferenc Bodon, Simon K Ward
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# For a copy of the GNU General Public License, visit 
# http://www.gnu.org or write to the Free Software Foundation, Inc.,
# 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
#######################################################

package Person;
use strict;
use warnings;
use Params::Validate qw(:all);
use Name;

sub new {
  my ( $classname, $id, $first_name, $last_name) = @_;
  my $self = {
     id    => $id,
     name => Name->new($first_name, $last_name),
     gender => undef,     #0 for male, 1 for female
     father => undef,
     mother => undef,
     email => undef,
     homepage => undef,
     date_of_birth => undef,
     date_of_death => undef,
     is_living => undef,   #1 for living, 0 for dead
     place_of_birth => undef,  # see Place.pm
     place_of_death => undef,  # see Place.pm
     cemetery => undef, # see Cemetery.pm
     schools => undef, #ARRAYREF of strings
     jobs => undef, #ARRAYREF of strings
     work_places => undef, #ARRAYREF of strings
     places_of_living => undef, #ARRAYREF of PLACEs
     general => undef,
     default_picture => undef, # see Picture.pm
#     pictures => undef, #ARRAYREF of pictures, see Picture.pm
  };
  return bless $self, $classname;
}
sub set_is_living {
  my ( $self, $is_living) = validate_pos(@_, 
    {type => HASHREF}, {type => SCALAR});
  $self->{is_living} = $is_living;    
}
sub set_place_of_birth {
  my ( $self, $place) = validate_pos(@_, 
    {type => HASHREF}, {type => HASHREF});
  $self->{place_of_birth} = $place;
    
}
sub set_place_of_death {
  my ( $self, $place) = validate_pos(@_, 
    {type => HASHREF}, {type => HASHREF});
  $self->{place_of_death} = $place;    
}
sub set_cemetery {
  my ( $self, $cemetery) = validate_pos(@_, 
    {type => HASHREF}, {type => HASHREF});
  $self->{cemetery} = $cemetery;
}

sub set_schools {
  my ( $self, $schools) = validate_pos(@_, 
    {type => HASHREF}, {type => ARRAYREF});
  $self->{schools} = $schools;
}
sub set_jobs {
  my ( $self, $jobs) = validate_pos(@_, 
    {type => HASHREF}, {type => ARRAYREF});
  $self->{jobs} = $jobs;
}
sub set_work_places {
  my ( $self, $work_places) = validate_pos(@_, 
    {type => HASHREF}, {type => ARRAYREF});
  $self->{work_places} = $work_places;
}
sub set_places_of_living {
  my ( $self, $places_of_living) = validate_pos(@_, 
    {type => HASHREF}, {type => ARRAYREF});
  $self->{places_of_living} = $places_of_living;
}
sub set_general {
  my ( $self, $general) = validate_pos(@_, 
    {type => HASHREF}, {type => SCALAR});
  $self->{general} = $general;
}
sub set_default_picture {
  my ( $self, $default_picture) = validate_pos(@_, 
    {type => HASHREF}, {type => HASHREF|UNDEF});
  $self->{default_picture} = $default_picture;
}
sub set_pictures {
  my ( $self, $pictures) = validate_pos(@_, 
    {type => HASHREF}, {type => ARRAYREF|UNDEF});
  $self->{pictures} = $pictures;
}
#######################################################
# converts a name to a url
# (removes middle name and converts spaces)
sub urlname {
  my ( $self ) = validate_pos(@_, {type => HASHREF});
  my $full_name = $self->full_name();
  $full_name =~ s/ /%20/g;
  return $full_name;
}
1;